@@ -43,12 +43,8 @@
 	#include <Windows.h>
 #endif
 
-#ifdef __VMS
-	#define __USE_STD_IOSTREAM 1
-	#include <assert>
-#else
-	#include <cassert>
-#endif
+#include <cassert>
+
 
 #include <clocale>		// needed by some compilers
 #include <cstdio>
